@@ -9,17 +9,11 @@ pub const LICENSE_TEXTS: &[(&str, &str)] = &[
     ("AFL-2.1", include!("text/licenses/AFL-2.1")),
     ("AFL-3.0", include!("text/licenses/AFL-3.0")),
     ("AGPL-1.0", include!("text/licenses/AGPL-1.0")),
-    ("AGPL-1.0-only", include!("text/licenses/AGPL-1.0-only")),
-    (
-        "AGPL-1.0-or-later",
-        include!("text/licenses/AGPL-1.0-or-later"),
-    ),
+    ("AGPL-1.0-only", include!("text/licenses/AGPL-1.0")),
+    ("AGPL-1.0-or-later", include!("text/licenses/AGPL-1.0")),
     ("AGPL-3.0", include!("text/licenses/AGPL-3.0")),
-    ("AGPL-3.0-only", include!("text/licenses/AGPL-3.0-only")),
-    (
-        "AGPL-3.0-or-later",
-        include!("text/licenses/AGPL-3.0-or-later"),
-    ),
+    ("AGPL-3.0-only", include!("text/licenses/AGPL-3.0")),
+    ("AGPL-3.0-or-later", include!("text/licenses/AGPL-3.0")),
     ("AMD-newlib", include!("text/licenses/AMD-newlib")),
     ("AMDPLPA", include!("text/licenses/AMDPLPA")),
     ("AML", include!("text/licenses/AML")),
@@ -215,7 +209,7 @@ pub const LICENSE_TEXTS: &[(&str, &str)] = &[
     ("CAL-1.0", include!("text/licenses/CAL-1.0")),
     (
         "CAL-1.0-Combined-Work-Exception",
-        include!("text/licenses/CAL-1.0-Combined-Work-Exception"),
+        include!("text/licenses/CAL-1.0"),
     ),
     ("CATOSL-1.1", include!("text/licenses/CATOSL-1.1")),
     ("CC-BY-1.0", include!("text/licenses/CC-BY-1.0")),
@@ -417,110 +411,95 @@ pub const LICENSE_TEXTS: &[(&str, &str)] = &[
     ("GD", include!("text/licenses/GD")),
     ("GFDL-1.1", include!("text/licenses/GFDL-1.1")),
     (
-        "GFDL-1.1-invariants",
-        include!("text/licenses/GFDL-1.1-invariants-only"),
+        "GFDL-1.1-invariants-only",
+        include!("text/licenses/GFDL-1.1"),
     ),
     (
         "GFDL-1.1-invariants-only",
-        include!("text/licenses/GFDL-1.1-invariants-only"),
+        include!("text/licenses/GFDL-1.1"),
     ),
     (
         "GFDL-1.1-invariants-or-later",
-        include!("text/licenses/GFDL-1.1-invariants-or-later"),
-    ),
-    (
-        "GFDL-1.1-no-invariants",
-        include!("text/licenses/GFDL-1.1-no-invariants-only"),
+        include!("text/licenses/GFDL-1.1"),
     ),
     (
         "GFDL-1.1-no-invariants-only",
-        include!("text/licenses/GFDL-1.1-no-invariants-only"),
+        include!("text/licenses/GFDL-1.1"),
+    ),
+    (
+        "GFDL-1.1-no-invariants-only",
+        include!("text/licenses/GFDL-1.1"),
     ),
     (
         "GFDL-1.1-no-invariants-or-later",
-        include!("text/licenses/GFDL-1.1-no-invariants-or-later"),
-    ),
-    ("GFDL-1.1-only", include!("text/licenses/GFDL-1.1-only")),
-    (
-        "GFDL-1.1-or-later",
-        include!("text/licenses/GFDL-1.1-or-later"),
+        include!("text/licenses/GFDL-1.1"),
     ),
+    ("GFDL-1.1-only", include!("text/licenses/GFDL-1.1")),
+    ("GFDL-1.1-or-later", include!("text/licenses/GFDL-1.1")),
     ("GFDL-1.2", include!("text/licenses/GFDL-1.2")),
     (
-        "GFDL-1.2-invariants",
-        include!("text/licenses/GFDL-1.2-invariants-only"),
+        "GFDL-1.2-invariants-only",
+        include!("text/licenses/GFDL-1.2"),
     ),
     (
         "GFDL-1.2-invariants-only",
-        include!("text/licenses/GFDL-1.2-invariants-only"),
+        include!("text/licenses/GFDL-1.2"),
     ),
     (
         "GFDL-1.2-invariants-or-later",
-        include!("text/licenses/GFDL-1.2-invariants-or-later"),
-    ),
-    (
-        "GFDL-1.2-no-invariants",
-        include!("text/licenses/GFDL-1.2-no-invariants-only"),
+        include!("text/licenses/GFDL-1.2"),
     ),
     (
         "GFDL-1.2-no-invariants-only",
-        include!("text/licenses/GFDL-1.2-no-invariants-only"),
+        include!("text/licenses/GFDL-1.2"),
+    ),
+    (
+        "GFDL-1.2-no-invariants-only",
+        include!("text/licenses/GFDL-1.2"),
     ),
     (
         "GFDL-1.2-no-invariants-or-later",
-        include!("text/licenses/GFDL-1.2-no-invariants-or-later"),
-    ),
-    ("GFDL-1.2-only", include!("text/licenses/GFDL-1.2-only")),
-    (
-        "GFDL-1.2-or-later",
-        include!("text/licenses/GFDL-1.2-or-later"),
+        include!("text/licenses/GFDL-1.2"),
     ),
+    ("GFDL-1.2-only", include!("text/licenses/GFDL-1.2")),
+    ("GFDL-1.2-or-later", include!("text/licenses/GFDL-1.2")),
     ("GFDL-1.3", include!("text/licenses/GFDL-1.3")),
     (
-        "GFDL-1.3-invariants",
-        include!("text/licenses/GFDL-1.3-invariants-only"),
+        "GFDL-1.3-invariants-only",
+        include!("text/licenses/GFDL-1.3"),
     ),
     (
         "GFDL-1.3-invariants-only",
-        include!("text/licenses/GFDL-1.3-invariants-only"),
+        include!("text/licenses/GFDL-1.3"),
     ),
     (
         "GFDL-1.3-invariants-or-later",
-        include!("text/licenses/GFDL-1.3-invariants-or-later"),
-    ),
-    (
-        "GFDL-1.3-no-invariants",
-        include!("text/licenses/GFDL-1.3-no-invariants-only"),
+        include!("text/licenses/GFDL-1.3"),
     ),
     (
         "GFDL-1.3-no-invariants-only",
-        include!("text/licenses/GFDL-1.3-no-invariants-only"),
+        include!("text/licenses/GFDL-1.3"),
+    ),
+    (
+        "GFDL-1.3-no-invariants-only",
+        include!("text/licenses/GFDL-1.3"),
     ),
     (
         "GFDL-1.3-no-invariants-or-later",
-        include!("text/licenses/GFDL-1.3-no-invariants-or-later"),
-    ),
-    ("GFDL-1.3-only", include!("text/licenses/GFDL-1.3-only")),
-    (
-        "GFDL-1.3-or-later",
-        include!("text/licenses/GFDL-1.3-or-later"),
+        include!("text/licenses/GFDL-1.3"),
     ),
+    ("GFDL-1.3-only", include!("text/licenses/GFDL-1.3")),
+    ("GFDL-1.3-or-later", include!("text/licenses/GFDL-1.3")),
     ("GL2PS", include!("text/licenses/GL2PS")),
     ("GLWTPL", include!("text/licenses/GLWTPL")),
     ("GPL-1.0", include!("text/licenses/GPL-1.0")),
+    ("GPL-1.0-only", include!("text/licenses/GPL-1.0")),
+    ("GPL-1.0-or-later", include!("text/licenses/GPL-1.0")),
     ("GPL-1.0+", include!("text/licenses/GPL-1.0+")),
-    ("GPL-1.0-only", include!("text/licenses/GPL-1.0-only")),
-    (
-        "GPL-1.0-or-later",
-        include!("text/licenses/GPL-1.0-or-later"),
-    ),
     ("GPL-2.0", include!("text/licenses/GPL-2.0")),
+    ("GPL-2.0-only", include!("text/licenses/GPL-2.0")),
+    ("GPL-2.0-or-later", include!("text/licenses/GPL-2.0")),
     ("GPL-2.0+", include!("text/licenses/GPL-2.0+")),
-    ("GPL-2.0-only", include!("text/licenses/GPL-2.0-only")),
-    (
-        "GPL-2.0-or-later",
-        include!("text/licenses/GPL-2.0-or-later"),
-    ),
     (
         "GPL-2.0-with-GCC-exception",
         include!("text/licenses/GPL-2.0-with-GCC-exception"),
@@ -542,12 +521,9 @@ pub const LICENSE_TEXTS: &[(&str, &str)] = &[
         include!("text/licenses/GPL-2.0-with-font-exception"),
     ),
     ("GPL-3.0", include!("text/licenses/GPL-3.0")),
+    ("GPL-3.0-only", include!("text/licenses/GPL-3.0")),
+    ("GPL-3.0-or-later", include!("text/licenses/GPL-3.0")),
     ("GPL-3.0+", include!("text/licenses/GPL-3.0+")),
-    ("GPL-3.0-only", include!("text/licenses/GPL-3.0-only")),
-    (
-        "GPL-3.0-or-later",
-        include!("text/licenses/GPL-3.0-or-later"),
-    ),
     (
         "GPL-3.0-with-GCC-exception",
         include!("text/licenses/GPL-3.0-with-GCC-exception"),
@@ -666,26 +642,17 @@ pub const LICENSE_TEXTS: &[(&str, &str)] = &[
     ("LAL-1.2", include!("text/licenses/LAL-1.2")),
     ("LAL-1.3", include!("text/licenses/LAL-1.3")),
     ("LGPL-2.0", include!("text/licenses/LGPL-2.0")),
+    ("LGPL-2.0-only", include!("text/licenses/LGPL-2.0")),
+    ("LGPL-2.0-or-later", include!("text/licenses/LGPL-2.0")),
     ("LGPL-2.0+", include!("text/licenses/LGPL-2.0+")),
-    ("LGPL-2.0-only", include!("text/licenses/LGPL-2.0-only")),
-    (
-        "LGPL-2.0-or-later",
-        include!("text/licenses/LGPL-2.0-or-later"),
-    ),
     ("LGPL-2.1", include!("text/licenses/LGPL-2.1")),
+    ("LGPL-2.1-only", include!("text/licenses/LGPL-2.1")),
+    ("LGPL-2.1-or-later", include!("text/licenses/LGPL-2.1")),
     ("LGPL-2.1+", include!("text/licenses/LGPL-2.1+")),
-    ("LGPL-2.1-only", include!("text/licenses/LGPL-2.1-only")),
-    (
-        "LGPL-2.1-or-later",
-        include!("text/licenses/LGPL-2.1-or-later"),
-    ),
     ("LGPL-3.0", include!("text/licenses/LGPL-3.0")),
+    ("LGPL-3.0-only", include!("text/licenses/LGPL-3.0")),
+    ("LGPL-3.0-or-later", include!("text/licenses/LGPL-3.0")),
     ("LGPL-3.0+", include!("text/licenses/LGPL-3.0+")),
-    ("LGPL-3.0-only", include!("text/licenses/LGPL-3.0-only")),
-    (
-        "LGPL-3.0-or-later",
-        include!("text/licenses/LGPL-3.0-or-later"),
-    ),
     ("LGPLLR", include!("text/licenses/LGPLLR")),
     ("LOOP", include!("text/licenses/LOOP")),
     ("LPD-document", include!("text/licenses/LPD-document")),
@@ -757,7 +724,7 @@ pub const LICENSE_TEXTS: &[(&str, &str)] = &[
     ("MPL-2.0", include!("text/licenses/MPL-2.0")),
     (
         "MPL-2.0-no-copyleft-exception",
-        include!("text/licenses/MPL-2.0-no-copyleft-exception"),
+        include!("text/licenses/MPL-2.0"),
     ),
     ("MS-LPL", include!("text/licenses/MS-LPL")),
     ("MS-PL", include!("text/licenses/MS-PL")),
@@ -805,7 +772,7 @@ pub const LICENSE_TEXTS: &[(&str, &str)] = &[
     ("NLOD-1.0", include!("text/licenses/NLOD-1.0")),
     ("NLOD-2.0", include!("text/licenses/NLOD-2.0")),
     ("NLPL", include!("text/licenses/NLPL")),
-    ("NOASSERTION", ""),
+    ("NOASSERTION", include!("text/licenses/NOASSERTION")),
     ("NOSL", include!("text/licenses/NOSL")),
     ("NPL-1.0", include!("text/licenses/NPL-1.0")),
     ("NPL-1.1", include!("text/licenses/NPL-1.1")),
@@ -829,11 +796,11 @@ pub const LICENSE_TEXTS: &[(&str, &str)] = &[
     ("ODbL-1.0", include!("text/licenses/ODbL-1.0")),
     ("OFFIS", include!("text/licenses/OFFIS")),
     ("OFL-1.0", include!("text/licenses/OFL-1.0")),
-    ("OFL-1.0-RFN", include!("text/licenses/OFL-1.0-RFN")),
-    ("OFL-1.0-no-RFN", include!("text/licenses/OFL-1.0-no-RFN")),
+    ("OFL-1.0-RFN", include!("text/licenses/OFL-1.0")),
+    ("OFL-1.0-no-RFN", include!("text/licenses/OFL-1.0")),
     ("OFL-1.1", include!("text/licenses/OFL-1.1")),
-    ("OFL-1.1-RFN", include!("text/licenses/OFL-1.1-RFN")),
-    ("OFL-1.1-no-RFN", include!("text/licenses/OFL-1.1-no-RFN")),
+    ("OFL-1.1-RFN", include!("text/licenses/OFL-1.1")),
+    ("OFL-1.1-no-RFN", include!("text/licenses/OFL-1.1")),
     ("OGC-1.0", include!("text/licenses/OGC-1.0")),
     ("OGDL-Taiwan-1.0", include!("text/licenses/OGDL-Taiwan-1.0")),
     ("OGL-Canada-2.0", include!("text/licenses/OGL-Canada-2.0")),
